#!/usr/bin/env python2.7
# -*- coding: utf-8 -*-

from os import environ, remove
import sys
from sqlite3 import IntegrityError
from django.conf import settings
from django.core import management

environ["DJANGO_SETTINGS_MODULE"] = "portail.settings"

from portailuser.models import PortailUser, Ecole
from django.db.models.base import ObjectDoesNotExist


def usage():
    sys.stderr.write(
        "Usage: {} create <username> <email> <password>\n".format(sys.argv[0])
        + "       {} password <username> <password>\n".format(sys.argv[0])
        + "       {} delete <username>\n".format(sys.argv[0])
    )

    sys.exit(2)


argc = len(sys.argv)

if argc < 2:
    usage()

if sys.argv[1] == "init" and argc == 2:
    try:
        remove(settings.DATABASES["default"]["NAME"])
    except OSError:
        print("Error deleting database (not yet created ?)...Going on")

    management.call_command("syncdb", verbosity=1, interactive=False)

    print("Création de l’utilisateur net7")
    u = PortailUser.objects.create_user("net7", "net7@bde.enseeiht.fr", Ecole.n7, "net7")
    u.is_superuser = True
    u.is_staff = True
    u.first_name = "Net"
    u.last_name = "Sept"
    u.save()


elif sys.argv[1] == "create" and argc == 5:
    try:
        u = PortailUser.objects.create_user(sys.argv[2], sys.argv[3], Ecole.n7, sys.argv[4])
        u.first_name = input("First Name:")
        u.last_name = input("Last Name:")
        u.save()
    except IntegrityError:
        sys.stderr.write("The user '{}' already exists!\n".format(sys.argv[2]))
        sys.exit(1)

elif sys.argv[1] == "password" and argc == 4:
    u = PortailUser.objects.get(username__exact=sys.argv[2])
    u.set_password(sys.argv[3])
    u.save()

elif sys.argv[1] == "delete" and argc == 3:
    try:
        u = PortailUser.objects.get(username__exact=sys.argv[2])
    except ObjectDoesNotExist:
        sys.stderr.write("The user '{}' does not exist!\n".format(sys.argv[2]))
        sys.exit(1)

    u.delete()

else:
    usage()
